==> libgnomedb-1.9.103.tar.bz2: libgnomedb-1.9.103/libgnomedb/libgnomedb.h <==
/* GNOME DB library
 * Copyright (C) 1999 - 2006 The GNOME Foundation.
 *
 * AUTHORS:
 * 	Rodrigo Moya <rodrigo@gnome-db.org>
 *      Vivien Malerba <malerba@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
 
#ifndef __LIBGNOME_DB_H_
#define __LIBGNOME_DB_H_

#include <libgda/libgda.h>
#include <libgnomedb/gnome-db-decl.h>
#include <libgnomedb/gnome-db-tools.h>

/* interfaces */
#include <libgnomedb/gnome-db-data-entry.h>
#include <libgnomedb/gnome-db-data-widget.h>

/* data data-entries widgets and cell renderers */
#include <libgnomedb/data-entries/gnome-db-data-cell-renderer-boolean.h>
#include <libgnomedb/data-entries/gnome-db-data-cell-renderer-combo.h>
#include <libgnomedb/data-entries/gnome-db-data-cell-renderer-info.h>
#include <libgnomedb/data-entries/gnome-db-data-cell-renderer-textual.h>
#include <libgnomedb/data-entries/gnome-db-entry-boolean.h>
#include <libgnomedb/data-entries/gnome-db-entry-combo.h>
#include <libgnomedb/data-entries/gnome-db-entry-none.h>
#include <libgnomedb/data-entries/gnome-db-entry-shell.h>
#include <libgnomedb/data-entries/gnome-db-entry-string.h>
#include <libgnomedb/data-entries/gnome-db-entry-common-time.h>
#include <libgnomedb/data-entries/gnome-db-entry-time.h>
#include <libgnomedb/data-entries/gnome-db-entry-date.h>
#include <libgnomedb/data-entries/gnome-db-entry-timestamp.h>
#include <libgnomedb/data-entries/gnome-db-entry-wrapper.h>

/* widgets and objects */
#include <libgnomedb/gnome-db-basic-form.h>
#include <libgnomedb/gnome-db-combo.h>
#include <libgnomedb/gnome-db-connection-properties.h>
#include <libgnomedb/gnome-db-data-source-selector.h>
#include <libgnomedb/gnome-db-data-store.h>
#include <libgnomedb/gnome-db-form.h>
#include <libgnomedb/gnome-db-data-import.h>
#include <libgnomedb/gnome-db-data-widget-info.h>
#include <libgnomedb/gnome-db-dbms-update-viewer.h>
#include <libgnomedb/gnome-db-dsn-config-druid.h>
#include <libgnomedb/gnome-db-dsn-config.h>
#include <libgnomedb/gnome-db-dsn-spec.h>
#include <libgnomedb/gnome-db-editor.h>
#include <libgnomedb/gnome-db-raw-form.h>
#include <libgnomedb/gnome-db-raw-grid.h>
#include <libgnomedb/gnome-db-grid.h>
#include <libgnomedb/gnome-db-error-dialog.h>
#include <libgnomedb/gnome-db-error.h>
#include <libgnomedb/gnome-db-find-dialog.h>
#include <libgnomedb/gnome-db-gray-bar.h>
#include <libgnomedb/gnome-db-login-dialog.h>
#include <libgnomedb/gnome-db-login.h>
#include <libgnomedb/gnome-db-provider-selector.h>
#include <libgnomedb/gnome-db-report-editor.h>
#include <libgnomedb/gnome-db-stock.h>
#include <libgnomedb/gnome-db-selector-private.h>
#include <libgnomedb/gnome-db-selector.h>
#include <libgnomedb/gnome-db-server-operation.h>
#include <libgnomedb/gnome-db-sql-console.h>

/* graphs */
#include <libgnomedb/graph/gnome-db-canvas-cursor.h>
#include <libgnomedb/graph/gnome-db-canvas-db-relations.h>
#include <libgnomedb/graph/gnome-db-canvas-entity.h>
#include <libgnomedb/graph/gnome-db-canvas-field.h>
#include <libgnomedb/graph/gnome-db-canvas-fkconstraint.h>
#include <libgnomedb/graph/gnome-db-canvas-item.h>
#include <libgnomedb/graph/gnome-db-canvas-join.h>
#include <libgnomedb/graph/gnome-db-canvas-query-struct.h>
#include <libgnomedb/graph/gnome-db-canvas-text.h>
#include <libgnomedb/graph/gnome-db-canvas-tip.h>
#include <libgnomedb/graph/gnome-db-canvas.h>

G_BEGIN_DECLS

void         gnome_db_init             (const gchar *app_id, const gchar *version, gint nargs, gchar *args[]);
void         gnome_db_main_run         (GdaInitFunc init_func, gpointer user_data);
void         gnome_db_main_quit        (void);

G_END_DECLS

#endif

==> libgnomedb-2.99.2.tar.bz2: libgnomedb-2.99.2/libgnomedb/libgnomedb.h <==
/* GNOME DB library
 * Copyright (C) 1999 - 2006 The GNOME Foundation.
 *
 * AUTHORS:
 * 	Rodrigo Moya <rodrigo@gnome-db.org>
 *      Vivien Malerba <malerba@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */
 
#ifndef __LIBGNOME_DB_H_
#define __LIBGNOME_DB_H_

#include <libgda/libgda.h>
#include <libgnomedb/gnome-db-decl.h>
#include <libgnomedb/gnome-db-tools.h>

/* interfaces */
#include <libgnomedb/gnome-db-data-entry.h>
#include <libgnomedb/gnome-db-data-widget.h>

/* data data-entries widgets and cell renderers */
#include <libgnomedb/data-entries/gnome-db-data-cell-renderer-boolean.h>
#include <libgnomedb/data-entries/gnome-db-data-cell-renderer-combo.h>
#include <libgnomedb/data-entries/gnome-db-data-cell-renderer-info.h>
#include <libgnomedb/data-entries/gnome-db-data-cell-renderer-textual.h>
#include <libgnomedb/data-entries/gnome-db-entry-boolean.h>
#include <libgnomedb/data-entries/gnome-db-entry-combo.h>
#include <libgnomedb/data-entries/gnome-db-entry-none.h>
#include <libgnomedb/data-entries/gnome-db-entry-shell.h>
#include <libgnomedb/data-entries/gnome-db-entry-string.h>
#include <libgnomedb/data-entries/gnome-db-entry-common-time.h>
#include <libgnomedb/data-entries/gnome-db-entry-time.h>
#include <libgnomedb/data-entries/gnome-db-entry-date.h>
#include <libgnomedb/data-entries/gnome-db-entry-timestamp.h>
#include <libgnomedb/data-entries/gnome-db-entry-wrapper.h>

/* widgets and objects */
#include <libgnomedb/gnome-db-basic-form.h>
#include <libgnomedb/gnome-db-combo.h>
#include <libgnomedb/gnome-db-connection-properties.h>
#include <libgnomedb/gnome-db-data-source-selector.h>
#include <libgnomedb/gnome-db-data-store.h>
#include <libgnomedb/gnome-db-form.h>
#include <libgnomedb/gnome-db-data-import.h>
#include <libgnomedb/gnome-db-data-widget-info.h>
#include <libgnomedb/gnome-db-dbms-update-viewer.h>
#include <libgnomedb/gnome-db-dsn-config-druid.h>
#include <libgnomedb/gnome-db-dsn-config.h>
#include <libgnomedb/gnome-db-dsn-spec.h>
#include <libgnomedb/gnome-db-editor.h>
#include <libgnomedb/gnome-db-raw-form.h>
#include <libgnomedb/gnome-db-raw-grid.h>
#include <libgnomedb/gnome-db-grid.h>
#include <libgnomedb/gnome-db-error-dialog.h>
#include <libgnomedb/gnome-db-error.h>
#include <libgnomedb/gnome-db-find-dialog.h>
#include <libgnomedb/gnome-db-gray-bar.h>
#include <libgnomedb/gnome-db-login-dialog.h>
#include <libgnomedb/gnome-db-login.h>
#include <libgnomedb/gnome-db-provider-selector.h>
#include <libgnomedb/gnome-db-report-editor.h>
#include <libgnomedb/gnome-db-stock.h>
#include <libgnomedb/gnome-db-selector.h>
#include <libgnomedb/gnome-db-server-operation.h>
#include <libgnomedb/gnome-db-sql-console.h>
#include <libgnomedb/gnome-db-transaction-status.h>

/* graphs */
#include <libgnomedb/graph/gnome-db-canvas-cursor.h>
#include <libgnomedb/graph/gnome-db-canvas-db-relations.h>
#include <libgnomedb/graph/gnome-db-canvas-entity.h>
#include <libgnomedb/graph/gnome-db-canvas-field.h>
#include <libgnomedb/graph/gnome-db-canvas-fkconstraint.h>
#include <libgnomedb/graph/gnome-db-canvas-item.h>
#include <libgnomedb/graph/gnome-db-canvas-join.h>
#include <libgnomedb/graph/gnome-db-canvas-query-struct.h>
#include <libgnomedb/graph/gnome-db-canvas-text.h>
#include <libgnomedb/graph/gnome-db-canvas-tip.h>
#include <libgnomedb/graph/gnome-db-canvas.h>

G_BEGIN_DECLS

void         gnome_db_init             (const gchar *app_id, const gchar *version, gint nargs, gchar *args[]);
void         gnome_db_main_run         (GdaInitFunc init_func, gpointer user_data);
void         gnome_db_main_quit        (void);

G_END_DECLS

#endif
